
From: Mauro Carvalho Chehab <mchehab@brturbo.com.br>

This patch fixes PAL-M chroma subcarrier frequency (FSC) to its correct
value of 3.5756115 MHz and adjusts horizontal total samples for PAL-M,
according with formula Line Draw Time / (4*FSC).

Signed-off-by: Mauro Carvalho Chehab <mchehab@brturbo.com.br>
Cc: <video4linux-list@redhat.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/media/video/cx88/cx88-core.c |    9 +++++++++
 1 files changed, 9 insertions(+)

diff -puN drivers/media/video/cx88/cx88-core.c~v4l-pal-m-chroma-subcarrier-frequency-fix drivers/media/video/cx88/cx88-core.c
--- 25/drivers/media/video/cx88/cx88-core.c~v4l-pal-m-chroma-subcarrier-frequency-fix	Mon May 23 17:04:09 2005
+++ 25-akpm/drivers/media/video/cx88/cx88-core.c	Mon May 23 17:04:09 2005
@@ -736,6 +736,10 @@ static unsigned int inline norm_fsc8(str
 {
 	static const unsigned int ntsc = 28636360;
 	static const unsigned int pal  = 35468950;
+	static const unsigned int palm  = 28604892;
+
+	if (norm->id & V4L2_STD_PAL_M)
+		return palm;
 
 	return (norm->id & V4L2_STD_625_50) ? pal : ntsc;
 }
@@ -749,6 +753,11 @@ static unsigned int inline norm_notchfil
 
 static unsigned int inline norm_htotal(struct cx88_tvnorm *norm)
 {
+	/* Should always be Line Draw Time / (4*FSC) */
+
+	if (norm->id & V4L2_STD_PAL_M)
+		return 909;
+
 	return (norm->id & V4L2_STD_625_50) ? 1135 : 910;
 }
 
_
